#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 31 16:06:51 2023

@author: benoit.jomain
"""


class Simple_Complex_Calculator:
    "Classe qui gère les opérations de nombres complexes"
    def __init__(self, t_1, t_2):
        self.t_1 = t_1
        self.t_2 = t_2

    def somme_imag(self):
        "Fonction somme imaginaire"
        return self.t_1[0] + self.t_2[0], self.t_1[1] + self.t_2[1]

    def difference_imag(self):
        "Fonction différence imaginaire"
        return self.t_1[0] - self.t_2[0], self.t_1[1] - self.t_2[1]

    def multiplication_imag(self):
        "Fonction multiplication imaginaire"
        return (
            self.t_1[0] * self.t_2[0] - self.t_1[1] * self.t_2[1],
            self.t_1[0] * self.t_2[1] + self.t_1[1] * self.t_2[0],
        )

    def division_imag(self):
        "Fonction division imaginaire"
        diviseur = self.t_2[0] ** 2 + self.t_2[1] ** 2
        return (self.t_1[0] * self.t_2[0] - self.t_1[1] * (-self.t_2[1])) / diviseur, (
            self.t_1[0] * (-self.t_2[1]) + self.t_1[1] * self.t_2[0]
        ) / diviseur


if __name__ == "__main__":
    CALCUL = Simple_Complex_Calculator((3, 2), (5, 4))
    print(CALCUL.difference_imag())
    print(CALCUL.division_imag())
    print(CALCUL.somme_imag())
    print(CALCUL.multiplication_imag())



#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Thu Feb  2 08:56:34 2023

@author: benoit.jomain
"""

from setuptools import setup

setup(
      name = 'Simple_Complex_Calulator',
      version = '0.1',
      packages = ["Package_Calculator"],
      install_requires = [],
      include_package_data = True,
      author = 'Benoit-Jomain',
      author_email = 'benoit.jomain@cpe.fr',
      description = 'Réaliser les différentes opérations élémentaires entre 2 nombres complexes : addition,différence,multiplication,division',
      classifiers = [
              'Programming Language :: Python :: 3',
              ],
      )


#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Wed Feb  1 13:43:40 2023

@author: benoit.jomain
"""
import unittest
import logging
from Package_Calculator import calculator as cal

class Test_Calculator_Operation(unittest.TestCase):
    """Classe de test qui vérifie les différentes opérations"""

    def setUp(self):
        """ Insanciation de la classe"""
        self.calcul = cal.Simple_Complex_Calculator((12, 10), (9, 7))
        self.log = logging.getLogger()

    def test_somme_imag(self):
        """Test de la méthode somme_imag"""
        res = self.calcul.somme_imag()
        self.assertEqual(res, (21, 17))
        self.log.info("La somme marche")

    def test_difference_imag(self):
        """Test de la méthode difference_imag"""
        res = self.calcul.difference_imag()
        self.assertEqual(res, (3, 3))
        self.log.info("La difference marche")

    def test_multiplication_imag(self):
        """Test de la méthode multiplication_imag"""
        res = self.calcul.multiplication_imag()
        self.assertEqual(res, (38, 174))
        self.log.info("La multiplication marche")

    def test_division_imag(self):
        """Test de la méthode division_imag"""
        res = self.calcul.division_imag()
        self.assertEqual(res, (1.3692307692307693, 0.046153846153846156))
        self.log.info("La division marche")

class Test_Calculator_float(unittest.TestCase):
    """Classe qui teste si les entrées pour chaque méthode sont bien des entiers"""
    def setUp(self):
        """Insanciation de la classe"""
        self.calcul = cal.Simple_Complex_Calculator((12.1, 10.1), (9.1, 7.23))
        self.log = logging.getLogger()

    def test_somme_imag(self):
        """Test de la méthode somme_imag pour savoir si les entrées sont des entiers"""
        res = self.calcul.somme_imag()
        self.assertEqual(res, "ERROR")
        self.log.warning("Vous n'entrez pas des entiers")

    def test_difference_imag(self):
        """Test de la méthode difference_imag pour savoir si les entrées sont des entiers"""
        res = self.calcul.difference_imag()
        self.assertEqual(res, "ERROR")
        self.log.warning("Vous n'entrez pas des entiers")

    def test_multiplication_imag(self):
        """Test de la méthode muliplication_imag pour savoir si les entrées sont des entiers"""
        res = self.calcul.multiplication_imag()
        self.assertEqual(res, "ERROR")
        self.log.warning("Vous n'entrez pas des entiers")

    def test_division_imag(self):
        """Test de la méthode division_imag pour savoir si les entrées sont des entiers"""
        res = self.calcul.division_imag()
        self.assertEqual(res, "ERROR")
        self.log.warning("Vous n'entrez pas des entiers")

class Test_Calculator_Division_Zero(unittest.TestCase):
    """Classe qui teste que la division par  renvoie ERROR"""

    def setUp(self):
        """Insanciation de la classe"""
        self.calcul = cal.Simple_Complex_Calculator((12.1, 10.1), (0, 0.0))
        self.log = logging.getLogger()

    def test_division_imag(self):
        """Test de la division par 0"""
        res = self.calcul.division_imag()
        self.assertEqual(res, "ERROR")
        self.log.error("Vous ne pouvrez pas diviser par 0")

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Wed Feb  1 13:58:19 2023

@author: benoit.jomain
"""
class Simple_Complex_Calculator:
    """Classe qui gère les opérations de nombres complexes où un nombre complexe est un tuple : (a,b) où a est la partie réelle et b la partie imaginaire  """
    def __init__(self, t_1, t_2):
        self.t_1 = t_1
        self.t_2 = t_2

    def somme_imag(self):
        """Fonction qui somme 2 nombres complexes"""
        if self.Verif_Entree_Saisi() == True :
            return self.t_1[0] + self.t_2[0], self.t_1[1] + self.t_2[1]
        return "ERROR"

    def difference_imag(self):
        """Fonction qui fait la différence entre 2 nombres imaginaires (t1 - t2)"""
        if self.Verif_Entree_Saisi() == True :
            return self.t_1[0] - self.t_2[0], self.t_1[1] - self.t_2[1]
        return "ERROR"

    def multiplication_imag(self):
        """Fonction qui multiplit 2 nombres imaginaires"""
        if self.Verif_Entree_Saisi() == True :
            return (
                self.t_1[0] * self.t_2[0] - self.t_1[1] * self.t_2[1],
                self.t_1[0] * self.t_2[1] + self.t_1[1] * self.t_2[0],
            )
        return "ERROR"

    def division_imag(self):
        """Fonction qui divise 2 nombres imaginaires (t1/t2)"""
        if self.Verif_Entree_Saisi() == True and (self.t_2[0] and self.t_2[1]) != 0 :
            diviseur = self.t_2[0] ** 2 + self.t_2[1] ** 2
            return (self.t_1[0] * self.t_2[0] - self.t_1[1] * (-self.t_2[1])) / diviseur, (
                self.t_1[0] * (-self.t_2[1]) + self.t_1[1] * self.t_2[0]
            ) / diviseur
        if (self.t_2[0] and self.t_2[1]) == 0 : 
            print("Vous ne pouvez pas diviser par 0")
        return "ERROR"
        
    def Verif_Entree_Saisi(self):
        if isinstance(self.t_1[0], int) and isinstance(self.t_1[1], int) and isinstance(self.t_2[0], int) and isinstance(self.t_2[1], int) :
            print("Entrées validées")
            return True
        print("Erreur")
        return "ERROR"